@@ -1,9 +1,7 @@
 package App::Prove::Plugin::Waivers;
-BEGIN {
-  $App::Prove::Plugin::Waivers::AUTHORITY = 'cpan:SCHWIGON';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: (incomplete) 'prove' plugin support for TAP::DOM::Waivers
-$App::Prove::Plugin::Waivers::VERSION = '0.002';
+$App::Prove::Plugin::Waivers::VERSION = '0.003';
 use strict;
 use warnings;
 
@@ -159,7 +157,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2020 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
